summaryrefslogtreecommitdiff
path: root/include/config.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/config.h')
-rw-r--r--include/config.h24
1 files changed, 15 insertions, 9 deletions
diff --git a/include/config.h b/include/config.h
index 5b2697ae93..c6a57bcf13 100644
--- a/include/config.h
+++ b/include/config.h
@@ -2634,22 +2634,20 @@
/*
* Define if this board can enable VBUS discharge (eg. through a GPIO-controlled
* discharge circuit, or through port controller registers) to discharge VBUS
- * rapidly on disconnect.
+ * rapidly on disconnect. Will be defined automatically when one of the below
+ * options is defined.
*/
#undef CONFIG_USB_PD_DISCHARGE
-/*
- * Define (along with CONFIG_USB_PD_DISCHARGE) if discharge circuit is
- * EC GPIO-controlled.
- */
+/* Define if discharge circuit is EC GPIO-controlled. */
#undef CONFIG_USB_PD_DISCHARGE_GPIO
/*
* Define (along with CONFIG_USB_PD_DISCHARGE) if discharge circuit is
* using PD discharge registers.
*/
#undef CONFIG_USB_PD_DISCHARGE_TCPC
+/* Define if discharge circuit is using PD discharge registers on PPC. */
+#undef CONFIG_USB_PD_DISCHARGE_PPC
+
/* Define if this board can act as a dual-role PD port (source and sink) */
#undef CONFIG_USB_PD_DUAL_ROLE
@@ -3274,6 +3272,14 @@
#endif /* CONFIG_EC_EC_COMM_BATTERY */
/*****************************************************************************/
+/* Define derived USB PD Discharge common path */
+#if defined(CONFIG_USB_PD_DISCHARGE_GPIO) || \
+ defined(CONFIG_USB_PD_DISCHARGE_TCPC) || \
+ defined(CONFIG_USB_PD_DISCHARGE_PPC)
+#define CONFIG_USB_PD_DISCHARGE
+#endif
+
+/*****************************************************************************/
/*
* Handle task-dependent configs.
*
@@ -2634,22 +2634,20 @@
#undef CONFIG_USB_PD_DISCHARGE_GPIO
-/*
- * Define (along with CONFIG_USB_PD_DISCHARGE) if discharge circuit is
- * using PD discharge registers.
- */
+/* Define if discharge circuit is using PD discharge registers on TCPC. */
#undef CONFIG_USB_PD_DISCHARGE_TCPC